"""
Copyright (c) 2010-present by Jaxl Innovations Private Limited.

All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, is strictly prohibited.
"""

import argparse


def _subparser(parser: argparse.ArgumentParser) -> None:
    """Manage Notifications (Android, iOS, Web)"""
    _subparsers = parser.add_subparsers(dest="action", required=True)


class JaxlNotificationsSDK:
    pass
